@@ -11,7 +11,7 @@ import toml as markup
 from .cli import init, config
 from .core import Config, init_pipeline
 from .questions import ask, build_prompt, questionnaire
-from .utils import remove_ansi
+from .utils import remove_ansi, rget
 
 
 config_file_name="%(program)s.%(extension)s" % dict(
